@@ -1,14 +1,16 @@
 # TOOL qc-cdna.R: cDNA (cDNA quality control using boxplots, density plots, and MA plots. This tool should be run on normalized data.)
 # INPUT normalized.tsv: normalized.tsv TYPE GENE_EXPRS 
-# OUTPUT boxplot.pdf: boxplot.pdf 
-# OUTPUT densityplot.pdf: densityplot.pdf 
-# OUTPUT OPTIONAL MA-plot.pdf: MA-plot.pdf 
+# INPUT META phenodata.tsv: phenodata.tsv TYPE GENERIC 
+# OUTPUT boxplot.png: boxplot.png 
+# OUTPUT densityplot.png: densityplot.png 
+# OUTPUT OPTIONAL MA-plot.png: MA-plot.png 
 # PARAMETER image.width: image.width TYPE INTEGER FROM 200 TO 3200 DEFAULT 600 (Width of the plotted network image)
 # PARAMETER image.height: image.height TYPE INTEGER FROM 200 TO 3200 DEFAULT 600 (Height of the plotted network image)
 
 # Quality control of cDNA chips
 # 30.6.2006 JTT
 # modified, IS, 12.10.2012, to cope with tables with gene descriptions (that typically contain 's)
+# modified, IS, 26.5.2013, use sample names from phenodata in plots, use png rather than pdf
 
 # Loads the libraries
 library(limma)
@@ -20,21 +22,23 @@ h<-image.height
 # Reads in the data
 file <- 'normalized.tsv'
 dat <- read.table(file, header=TRUE, sep='\t', quote='', row.names=1, check.names=FALSE)
+phenodata <- read.table("phenodata.tsv", header=TRUE, sep="\t", as.is=TRUE)
 
 # Separates expression values and flags
 calls<-dat[,grep("flag", names(dat))]
 dat2<-dat[,grep("chip", names(dat))]
+colnames(dat2) <- phenodata$description
 A<-dat[,grep("average", names(dat))]
 
 # Producing some basic plots of the data
 
 # Boxplot
-pdf(file="boxplot.pdf", width=w/72, height=h/72)
+bitmap(file="boxplot.png", width=w/72, height=h/72)
 boxplot(as.data.frame(dat2), las=2, cex.axis=0.5)
 dev.off()
 
 # Density plot
-pdf(file="densityplot.pdf", width=w/72, height=h/72)
+bitmap(file="densityplot.png", width=w/72, height=h/72)
 x<-c()
 y<-c()
 for(i in 1:ncol(dat2)) {
@@ -50,12 +54,12 @@ dev.off()
 
 # MA plot
 if (ncol(A) > 0) {
-  pdf(file="MA-plot.pdf", width=w/72, height=h/72)
+  bitmap(file="MA-plot.png", width=w/72, height=h/72)
   par(mfrow=c(ceiling(sqrt(ncol(dat2))), ceiling(sqrt(ncol(dat2)))))
   ylim<-c(min(na.omit(dat2)), max(na.omit(dat2)))
   for(i in 1:ncol(dat2)) {
     par(mar=c(0, 1, 1, 0)+0.1)
-    plot(A[,i], dat2[,i], xaxt="n", xlab=NULL, ylab=NULL, main=paste("Chip", i, sep=" "), cex.main=0.75, cex.axis=0.7, cex.lab=0.75, tck=-0.01, mgp=c(3,0.2,0), ylim=ylim)
+    plot(A[,i], dat2[,i], xaxt="n", xlab=NULL, ylab=NULL, main=phenodata$description[i], cex.main=0.75, cex.axis=0.7, cex.lab=0.75, tck=-0.01, mgp=c(3,0.2,0), ylim=ylim)
     d<-na.omit(data.frame(A=A[,i], dat=dat2[,i]))
     lines(lowess(d$A, d$dat), col="red")
   }
