@@ -9,10 +9,10 @@ import fi.csc.microarray.client.Session;
 import fi.csc.microarray.client.operation.Operation;
 import fi.csc.microarray.client.operation.OperationRecord;
 import fi.csc.microarray.client.tasks.Task;
-import fi.csc.microarray.client.visualisation.methods.gbrowser.stack.BedLineParser;
-import fi.csc.microarray.client.visualisation.methods.gbrowser.stack.GtfLineParser;
-import fi.csc.microarray.client.visualisation.methods.gbrowser.stack.TsvLineParser;
-import fi.csc.microarray.client.visualisation.methods.gbrowser.stack.VcfLineParser;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.runtimeIndex.BedLineParser;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.runtimeIndex.GtfLineParser;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.runtimeIndex.TsvLineParser;
+import fi.csc.microarray.client.visualisation.methods.gbrowser.runtimeIndex.VcfLineParser;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.util.ChromosomeNormaliser;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.util.SamBamUtils;
 import fi.csc.microarray.client.visualisation.methods.gbrowser.util.SamBamUtils.SamBamUtilState;
@@ -154,6 +154,7 @@ public class LocalNGSPreprocess implements Runnable {
 		OperationRecord operationRecord = new OperationRecord(new Operation(Session.getSession().getApplication().getOperationDefinition(task.getOperationID()), new DataBean[] {}));
 		outputBean.setOperationRecord(operationRecord);
 		indexOutputBean.setOperationRecord(operationRecord);
+		//Chipster2 backport fix
 		dataManager.getRootFolder().addChild(outputBean);
 		dataManager.getRootFolder().addChild(indexOutputBean);
 	}
@@ -185,6 +186,7 @@ public class LocalNGSPreprocess implements Runnable {
 		
 		// Create new operation instance, without any inputs FIXME parameters are lost, sucks create OperationRecord directly
 		outputBean.setOperationRecord(new OperationRecord(new Operation(Session.getSession().getApplication().getOperationDefinition(task.getOperationID()), new DataBean[] {})));
+		//Chipster2 backport fix
 		dataManager.getRootFolder().addChild(outputBean);
 	}
 }
